Quark Report

# Quark Rule Generation Reviewer & Editor

Sample Information
File name
  Ahmyth.apk
File size
  0.26 Mb
MD5
  893e05aabd8754236ea70d3da8363d52
The Number of Generated Rules: $rule_numbers$
Search Rules

## Edit rule information

Description

Score

Labels

telephony command privacy control connection calllog sms power exec applications wifi account camera phone contact network evasion record so pin reflection notification permission http file collection accounts socket dexClassLoader calendar lock accessibility location packer

No. | API 1 | API 2 | Edit & Save
--- | --- | --- | ---
$genrule_report$

$report_data$